from django.db import models  

class Person(models.Model):  
    pid = models.CharField(max_length=20)  
    fname = models.CharField(max_length=20)  
    lname = models.CharField(max_length=20)
    password = models.CharField(max_length=20)
    is_prof = models.BooleanField(default=False) 

    def __str__(self):
        return "%s %s" % (self.fname, self.lname)

    class Meta:  
        db_table = "person" 

class Subject(models.Model):  
    sub_code = models.CharField(max_length=5)
    sub_name = models.CharField(max_length=100) 
    sub_detail = models.CharField(max_length=500)
    prof = models.ForeignKey(Person, on_delete=models.CASCADE) 

    def __str__(self):
        return self.sub_code

    class Meta:  
        db_table = "subject"

class Subject_Student(models.Model):
    subject = models.ForeignKey(Subject, on_delete=models.CASCADE)
    student = models.ForeignKey(Person, on_delete=models.CASCADE)
    is_accepted = models.BooleanField(default=False)

    class Meta:  
        db_table = "subject_student"
    def __str__(self):
        return "%s %s" % (self.student.fname, self.subject.sub_name)


class Topic(models.Model):  
    title = models.CharField(max_length=100) 
    subject = models.ForeignKey(Subject, on_delete=models.CASCADE)
    is_prof_included = models.BooleanField(default=True)

    def __str__(self):
        return "%s %s %d" % (self.title, self.subject.sub_name, self.id)

    class Meta:  
        db_table = "topic"

class Thread(models.Model):  
    title = models.CharField(max_length=50)
    msg = models.CharField(max_length=500) 
    topic = models.ForeignKey(Topic, on_delete=models.CASCADE) 
    person = models.ForeignKey(Person, on_delete=models.CASCADE)
    likes = models.IntegerField(default=0)
    dislikes = models.IntegerField(default=0)
    time = models.DateTimeField(auto_now_add=True, blank=True)

    def __str__(self):
        return "%s %s" % (self.title, self.topic.title)

    class Meta:  
        db_table = "thread"

class Like(models.Model):   
    thread = models.ForeignKey(Thread, on_delete=models.CASCADE) 
    person = models.ForeignKey(Person, on_delete=models.CASCADE)
    is_liked = models.BooleanField(default=True) 

    def __str__(self):
        return str(self.id)

    class Meta:  
        db_table = "like"